DWImagePickerPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • DWImagePickerPlatform

Constructors

DWImagePickerPlatform()
Constructs a DWImagePickerPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openCamera({DWCameraOptions? cameraOptions, bool? cropping, DWCropOptions? cropOptions, LocalizedImageCropper? localized}) Future<DWPickerItem>
openCropper(String imagePath, {DWCropOptions? cropOptions, LocalizedImageCropper? localized}) Future<DWPickerItem>
openPicker({List<String>? selectedIds, DWPickerOptions? pickerOptions, bool? cropping, DWCropOptions? cropOptions, LocalizedImagePicker? localized}) Future<List<DWPickerItem>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DWImagePickerPlatform
The default instance of DWImagePickerPlatform to use.
getter/setter pair